@@ -1,36 +1,88 @@
 """Constants for the Z-Wave JS python library."""
-from dataclasses import dataclass
 from enum import Enum, IntEnum
 from typing import Dict, List
 
 # minimal server schema version we can handle
-MIN_SERVER_SCHEMA_VERSION = 1
+MIN_SERVER_SCHEMA_VERSION = 3
 # max server schema version we can handle (and our code is compatible with)
-MAX_SERVER_SCHEMA_VERSION = 1
+MAX_SERVER_SCHEMA_VERSION = 3
 
 VALUE_UNKNOWN = "unknown"
 
 
-class LogLevel(IntEnum):
+class CommandStatus(str, Enum):
+    """Status of a command sent to zwave-js-server."""
+
+    ACCEPTED = "accepted"
+    QUEUED = "queued"
+
+
+class EntryControlEventType(IntEnum):
+    """Entry control event types."""
+
+    # https://github.com/zwave-js/node-zwave-js/blob/master/packages/zwave-js/src/lib/commandclass/EntryControlCC.ts#L54
+    CACHING = 0
+    CACHED_KEYS = 1
+    ENTER = 2
+    DISARM_ALL = 3
+    ARM_ALL = 4
+    ARM_AWAY = 5
+    ARM_HOME = 6
+    EXIT_DELAY = 7
+    ARM1 = 8
+    ARM2 = 9
+    ARM3 = 10
+    ARM4 = 11
+    ARM5 = 12
+    ARM6 = 13
+    RFID = 14
+    BELL = 15
+    FIRE = 16
+    POLICE = 17
+    ALERT_PANIC = 18
+    ALERT_MEDICAL = 19
+    GATE_OPEN = 20
+    GATE_CLOSE = 21
+    LOCK = 22
+    UNLOCK = 23
+    TEST = 24
+    CANCEL = 25
+
+
+class EntryControlDataType(IntEnum):
+    """Entry control data types."""
+
+    # https://github.com/zwave-js/node-zwave-js/blob/master/packages/zwave-js/src/lib/commandclass/EntryControlCC.ts#L83
+    NONE = 0
+    RAW = 1
+    ASCII = 2
+    MD5 = 3
+
+
+class ProtocolVersion(IntEnum):
+    """Protocol version."""
+
+    # https://github.com/zwave-js/node-zwave-js/blob/master/packages/zwave-js/src/lib/node/Types.ts#L149
+    UNKNOWN = 0
+    VERSION_2_0 = 1
+    VERSION_4_2X_OR_5_0X = 2
+    VERSION_4_5X_OR_6_0X = 3
+
+
+# Multiple inheritance so that LogLevel will JSON serialize properly
+# Reference: https://stackoverflow.com/a/51976841
+class LogLevel(str, Enum):
     """Enum for log levels used by node-zwave-js."""
 
     # https://github.com/zwave-js/node-zwave-js/blob/master/packages/core/src/log/shared.ts#L12
     # https://github.com/winstonjs/triple-beam/blame/master/config/npm.js#L14
-    ERROR = 0
-    WARN = 1
-    INFO = 2
-    HTTP = 3
-    VERBOSE = 4
-    DEBUG = 5
-    SILLY = 6
-
-
-@dataclass
-class PropertyKey:
-    """Class to represent a property key and its name."""
-
-    key: int
-    name: str
+    ERROR = "error"
+    WARN = "warn"
+    INFO = "info"
+    HTTP = "http"
+    VERBOSE = "verbose"
+    DEBUG = "debug"
+    SILLY = "silly"
 
 
 class CommandClass(IntEnum):
@@ -184,7 +236,7 @@ class CodeSlotStatus(IntEnum):
     DISABLED = 2
 
 
-# Depending on the Commmand Class being used by the lock, the lock state is
+# Depending on the Command Class being used by the lock, the lock state is
 # different so we need a map to track it
 LOCK_CMD_CLASS_TO_LOCKED_STATE_MAP = {
     CommandClass.DOOR_LOCK: DoorLockMode.SECURED,
@@ -253,7 +305,7 @@ class ThermostatOperatingState(IntEnum):
     THIRD_STAGE_AUX_HEAT = 11
 
 
-class ThermostatSetpointType(Enum):
+class ThermostatSetpointType(IntEnum):
     """
     Enum with all (known/used) Z-Wave Thermostat Setpoint Types.
 
@@ -261,18 +313,18 @@ class ThermostatSetpointType(Enum):
     """
 
     # https://github.com/zwave-js/node-zwave-js/blob/master/packages/zwave-js/src/lib/commandclass/ThermostatSetpointCC.ts#L53-L66
-    NA = PropertyKey(0, "N/A")
-    HEATING = PropertyKey(1, "Heating")
-    COOLING = PropertyKey(2, "Cooling")
-    FURNACE = PropertyKey(7, "Furnace")
-    DRY_AIR = PropertyKey(8, "Dry Air")
-    MOIST_AIR = PropertyKey(9, "Moist Air")
-    AUTO_CHANGEOVER = PropertyKey(10, "Auto Changeover")
-    ENERGY_SAVE_HEATING = PropertyKey(11, "Energy Save Heating")
-    ENERGY_SAVE_COOLING = PropertyKey(12, "Energy Save Cooling")
-    AWAY_HEATING = PropertyKey(13, "Away Heating")
-    AWAY_COOLING = PropertyKey(14, "Away Cooling")
-    FULL_POWER = PropertyKey(15, "Full Power")
+    NA = 0
+    HEATING = 1
+    COOLING = 2
+    FURNACE = 7
+    DRY_AIR = 8
+    MOIST_AIR = 9
+    AUTO_CHANGEOVER = 10
+    ENERGY_SAVE_HEATING = 11
+    ENERGY_SAVE_COOLING = 12
+    AWAY_HEATING = 13
+    AWAY_COOLING = 14
+    FULL_POWER = 15
 
 
 # In Z-Wave the modes and presets are both in ThermostatMode.
@@ -312,6 +364,7 @@ class ConfigurationValueType(Enum):
     """Enum for configuration value types."""
 
     ENUMERATED = "enumerated"
+    MANUAL_ENTRY = "manual_entry"
     RANGE = "range"
     UNDEFINED = "undefined"
 
@@ -335,16 +388,16 @@ class BarrierState(IntEnum):
     OPEN = 255
 
 
-class ColorComponent(Enum):
+class ColorComponent(IntEnum):
     """Enum with all (known/used) Color Switch CC colors."""
 
     # https://github.com/zwave-js/node-zwave-js/blob/master/packages/zwave-js/src/lib/commandclass/ColorSwitchCC.ts#L62
-    WARM_WHITE = PropertyKey(0, "Warm White")
-    COLD_WHITE = PropertyKey(1, "Cold White")
-    RED = PropertyKey(2, "Red")
-    GREEN = PropertyKey(3, "Green")
-    BLUE = PropertyKey(4, "Blue")
-    AMBER = PropertyKey(5, "Amber")
-    CYAN = PropertyKey(6, "Cyan")
-    PURPLE = PropertyKey(7, "Purple")
-    INDEX = PropertyKey(8, "Index")
+    WARM_WHITE = 0
+    COLD_WHITE = 1
+    RED = 2
+    GREEN = 3
+    BLUE = 4
+    AMBER = 5
+    CYAN = 6
+    PURPLE = 7
+    INDEX = 8
