@@ -6,12 +6,15 @@ https://zwave-js.github.io/node-zwave-js/#/api/endpoint?id=endpoint-properties
 
 from typing import Optional, TypedDict
 
+from .device_class import DeviceClass, DeviceClassDataType
+
 
 class EndpointDataType(TypedDict, total=False):
     """Represent an endpoint data dict type."""
 
     nodeId: int  # required
     index: int  # required
+    deviceClass: DeviceClassDataType  # required
     installerIcon: int
     userIcon: int
 
@@ -33,6 +36,11 @@ class Endpoint:
         """Return index property."""
         return self.data["index"]
 
+    @property
+    def device_class(self) -> DeviceClass:
+        """Return the device_class."""
+        return DeviceClass(self.data["deviceClass"])
+
     @property
     def installer_icon(self) -> Optional[int]:
         """Return installer icon property."""
